var doIt = () => console.log('main');

doIt();

export { doIt as default };
